AppControlSet

Struct AppControlSet 

pub struct AppControlSet { /* private fields */ }
📶 A set of application control notices.


📍 run/app/control


Implementations

Source

impl AppControlSet

pub const fn to_linux_signals(self) -> LinuxSignalSet

Available on crate feature _linux_abi only.

Returns the Linux signals needed to receive these app controls.

Source

impl AppControlSet

pub fn for_each(self, f: impl FnMut(AppControl))

Calls f for each control notice in this set.

Source

impl AppControlSet

Named constants

pub const Interrupt: Self

1 The bit index that corresponds to AppControl::Interrupt.

pub const Quit: Self

1 The bit index that corresponds to AppControl::Quit.

pub const Terminate: Self

1 The bit index that corresponds to AppControl::Terminate.

pub const Hangup: Self

1 The bit index that corresponds to AppControl::Hangup.

pub const Suspend: Self

1 The bit index that corresponds to AppControl::Suspend.

pub const Resume: Self

1 The bit index that corresponds to AppControl::Resume.

pub const Close: Self

1 The bit index that corresponds to AppControl::Close.

pub const Logout: Self

1 The bit index that corresponds to AppControl::Logout.

pub const Shutdown: Self

1 The bit index that corresponds to AppControl::Shutdown.

Source

impl AppControlSet

Convenience methods derived from each named constant.

pub const fn has_interrupt(self) -> bool

Returns true if Interrupt is present.

pub const fn contains_interrupt(self) -> bool

Returns true if all bits in Interrupt are present.

pub const fn intersects_interrupt(self) -> bool

Returns true if the set shares any bit with Interrupt.

pub const fn with_interrupt(self) -> Self

Returns self with Interrupt inserted.

pub const fn with_interrupt_if(self, condition: bool) -> Self

Returns self with Interrupt inserted if condition is true.

pub const fn without_interrupt(self) -> Self

Returns self with Interrupt removed.

pub const fn set_interrupt(&mut self)

Sets Interrupt.

pub const fn set_interrupt_if(&mut self, condition: bool)

Sets Interrupt if condition is true.

pub const fn unset_interrupt(&mut self)

Unsets Interrupt.

pub const fn has_quit(self) -> bool

Returns true if Quit is present.

pub const fn contains_quit(self) -> bool

Returns true if all bits in Quit are present.

pub const fn intersects_quit(self) -> bool

Returns true if the set shares any bit with Quit.

pub const fn with_quit(self) -> Self

Returns self with Quit inserted.

pub const fn with_quit_if(self, condition: bool) -> Self

Returns self with Quit inserted if condition is true.

pub const fn without_quit(self) -> Self

Returns self with Quit removed.

pub const fn set_quit(&mut self)

Sets Quit.

pub const fn set_quit_if(&mut self, condition: bool)

Sets Quit if condition is true.

pub const fn unset_quit(&mut self)

Unsets Quit.

pub const fn has_terminate(self) -> bool

Returns true if Terminate is present.

pub const fn contains_terminate(self) -> bool

Returns true if all bits in Terminate are present.

pub const fn intersects_terminate(self) -> bool

Returns true if the set shares any bit with Terminate.

pub const fn with_terminate(self) -> Self

Returns self with Terminate inserted.

pub const fn with_terminate_if(self, condition: bool) -> Self

Returns self with Terminate inserted if condition is true.

pub const fn without_terminate(self) -> Self

Returns self with Terminate removed.

pub const fn set_terminate(&mut self)

Sets Terminate.

pub const fn set_terminate_if(&mut self, condition: bool)

Sets Terminate if condition is true.

pub const fn unset_terminate(&mut self)

Unsets Terminate.

pub const fn has_hangup(self) -> bool

Returns true if Hangup is present.

pub const fn contains_hangup(self) -> bool

Returns true if all bits in Hangup are present.

pub const fn intersects_hangup(self) -> bool

Returns true if the set shares any bit with Hangup.

pub const fn with_hangup(self) -> Self

Returns self with Hangup inserted.

pub const fn with_hangup_if(self, condition: bool) -> Self

Returns self with Hangup inserted if condition is true.

pub const fn without_hangup(self) -> Self

Returns self with Hangup removed.

pub const fn set_hangup(&mut self)

Sets Hangup.

pub const fn set_hangup_if(&mut self, condition: bool)

Sets Hangup if condition is true.

pub const fn unset_hangup(&mut self)

Unsets Hangup.

pub const fn has_suspend(self) -> bool

Returns true if Suspend is present.

pub const fn contains_suspend(self) -> bool

Returns true if all bits in Suspend are present.

pub const fn intersects_suspend(self) -> bool

Returns true if the set shares any bit with Suspend.

pub const fn with_suspend(self) -> Self

Returns self with Suspend inserted.

pub const fn with_suspend_if(self, condition: bool) -> Self

Returns self with Suspend inserted if condition is true.

pub const fn without_suspend(self) -> Self

Returns self with Suspend removed.

pub const fn set_suspend(&mut self)

Sets Suspend.

pub const fn set_suspend_if(&mut self, condition: bool)

Sets Suspend if condition is true.

pub const fn unset_suspend(&mut self)

Unsets Suspend.

pub const fn has_resume(self) -> bool

Returns true if Resume is present.

pub const fn contains_resume(self) -> bool

Returns true if all bits in Resume are present.

pub const fn intersects_resume(self) -> bool

Returns true if the set shares any bit with Resume.

pub const fn with_resume(self) -> Self

Returns self with Resume inserted.

pub const fn with_resume_if(self, condition: bool) -> Self

Returns self with Resume inserted if condition is true.

pub const fn without_resume(self) -> Self

Returns self with Resume removed.

pub const fn set_resume(&mut self)

Sets Resume.

pub const fn set_resume_if(&mut self, condition: bool)

Sets Resume if condition is true.

pub const fn unset_resume(&mut self)

Unsets Resume.

pub const fn has_close(self) -> bool

Returns true if Close is present.

pub const fn contains_close(self) -> bool

Returns true if all bits in Close are present.

pub const fn intersects_close(self) -> bool

Returns true if the set shares any bit with Close.

pub const fn with_close(self) -> Self

Returns self with Close inserted.

pub const fn with_close_if(self, condition: bool) -> Self

Returns self with Close inserted if condition is true.

pub const fn without_close(self) -> Self

Returns self with Close removed.

pub const fn set_close(&mut self)

Sets Close.

pub const fn set_close_if(&mut self, condition: bool)

Sets Close if condition is true.

pub const fn unset_close(&mut self)

Unsets Close.

pub const fn has_logout(self) -> bool

Returns true if Logout is present.

pub const fn contains_logout(self) -> bool

Returns true if all bits in Logout are present.

pub const fn intersects_logout(self) -> bool

Returns true if the set shares any bit with Logout.

pub const fn with_logout(self) -> Self

Returns self with Logout inserted.

pub const fn with_logout_if(self, condition: bool) -> Self

Returns self with Logout inserted if condition is true.

pub const fn without_logout(self) -> Self

Returns self with Logout removed.

pub const fn set_logout(&mut self)

Sets Logout.

pub const fn set_logout_if(&mut self, condition: bool)

Sets Logout if condition is true.

pub const fn unset_logout(&mut self)

Unsets Logout.

pub const fn has_shutdown(self) -> bool

Returns true if Shutdown is present.

pub const fn contains_shutdown(self) -> bool

Returns true if all bits in Shutdown are present.

pub const fn intersects_shutdown(self) -> bool

Returns true if the set shares any bit with Shutdown.

pub const fn with_shutdown(self) -> Self

Returns self with Shutdown inserted.

pub const fn with_shutdown_if(self, condition: bool) -> Self

Returns self with Shutdown inserted if condition is true.

pub const fn without_shutdown(self) -> Self

Returns self with Shutdown removed.

pub const fn set_shutdown(&mut self)

Sets Shutdown.

pub const fn set_shutdown_if(&mut self, condition: bool)

Sets Shutdown if condition is true.

pub const fn unset_shutdown(&mut self)

Unsets Shutdown.

Source

impl AppControlSet

Common set methods

pub const fn new() -> Self

Returns an empty set.

pub const fn from_bits(bits: u16) -> Self

Returns a set from raw bits.

pub const fn bits(self) -> u16

Returns the raw backing bits.

pub const fn all() -> Self

Returns the union of all declared sets.

pub const fn is_empty(self) -> bool

Returns true if no bits are set.

pub const fn is_full(self) -> bool

Returns true if all the declared bits are set.

pub const fn contains(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn has(self, other: Self) -> bool

An alias of contains.

pub const fn with(self, other: Self) -> Self

Returns self with other inserted.

pub const fn with_if(self, condition: bool, other: Self) -> Self

Returns self with other inserted if condition is true.

pub const fn without(self, other: Self) -> Self

Returns self with other removed.

pub const fn toggled(self, other: Self) -> Self

Returns self with other toggled.

Source

impl AppControlSet

Set operations

pub const fn intersects(self, other: Self) -> bool

Returns true if self and other share any bit.

pub const fn is_subset(self, other: Self) -> bool

Returns true if all bits in self are also set in other.

pub const fn is_superset(self, other: Self) -> bool

Returns true if all bits in other are also set in self.

pub const fn union(self, other: Self) -> Self

Returns the union of self and other.

pub const fn intersection(self, other: Self) -> Self

Returns the intersection of self and other.

pub const fn difference(self, other: Self) -> Self

Returns the difference of self and other.

pub const fn symmetric_difference(self, other: Self) -> Self

Returns the symmetric difference of self and other.

Source

impl AppControlSet

Mutating set operations

pub const fn clear(&mut self)

Clears the set.

pub const fn insert(&mut self, other: Self)

Inserts all bits from other.

pub const fn remove(&mut self, other: Self)

Removes all bits from other.

pub const fn toggle(&mut self, other: Self)

Toggles all bits from other.