pub struct AppControlSet { /* private fields */ }Expand description
Implementations
Sourceimpl AppControlSet
impl AppControlSet
Sourcepub const fn to_linux_signals(self) -> LinuxSignalSet
Available on crate feature _linux_abi only.
pub const fn to_linux_signals(self) -> LinuxSignalSet
_linux_abi only.Returns the Linux signals needed to receive these app controls.
Sourceimpl AppControlSet
impl AppControlSet
Sourcepub fn for_each(self, f: impl FnMut(AppControl))
pub fn for_each(self, f: impl FnMut(AppControl))
Calls f for each control notice in this set.
Sourceimpl AppControlSet
Named constants
impl AppControlSet
Named constants
Sourceimpl AppControlSet
Convenience methods derived from each named constant.
impl AppControlSet
Convenience methods derived from each named constant.
Sourcepub const fn has_interrupt(self) -> bool
pub const fn has_interrupt(self) -> bool
Returns true if Interrupt is present.
Sourcepub const fn contains_interrupt(self) -> bool
pub const fn contains_interrupt(self) -> bool
Returns true if all bits in Interrupt are present.
Sourcepub const fn intersects_interrupt(self) -> bool
pub const fn intersects_interrupt(self) -> bool
Returns true if the set shares any bit with Interrupt.
Sourcepub const fn with_interrupt(self) -> Self
pub const fn with_interrupt(self) -> Self
Returns self with Interrupt inserted.
Sourcepub const fn with_interrupt_if(self, condition: bool) -> Self
pub const fn with_interrupt_if(self, condition: bool) -> Self
Returns self with Interrupt inserted if condition is true.
Sourcepub const fn without_interrupt(self) -> Self
pub const fn without_interrupt(self) -> Self
Returns self with Interrupt removed.
Sourcepub const fn set_interrupt(&mut self)
pub const fn set_interrupt(&mut self)
Sets Interrupt.
Sourcepub const fn set_interrupt_if(&mut self, condition: bool)
pub const fn set_interrupt_if(&mut self, condition: bool)
Sets Interrupt if condition is true.
Sourcepub const fn unset_interrupt(&mut self)
pub const fn unset_interrupt(&mut self)
Unsets Interrupt.
Sourcepub const fn contains_quit(self) -> bool
pub const fn contains_quit(self) -> bool
Returns true if all bits in Quit are present.
Sourcepub const fn intersects_quit(self) -> bool
pub const fn intersects_quit(self) -> bool
Returns true if the set shares any bit with Quit.
Sourcepub const fn with_quit_if(self, condition: bool) -> Self
pub const fn with_quit_if(self, condition: bool) -> Self
Returns self with Quit inserted if condition is true.
Sourcepub const fn without_quit(self) -> Self
pub const fn without_quit(self) -> Self
Returns self with Quit removed.
Sourcepub const fn set_quit_if(&mut self, condition: bool)
pub const fn set_quit_if(&mut self, condition: bool)
Sets Quit if condition is true.
Sourcepub const fn unset_quit(&mut self)
pub const fn unset_quit(&mut self)
Unsets Quit.
Sourcepub const fn has_terminate(self) -> bool
pub const fn has_terminate(self) -> bool
Returns true if Terminate is present.
Sourcepub const fn contains_terminate(self) -> bool
pub const fn contains_terminate(self) -> bool
Returns true if all bits in Terminate are present.
Sourcepub const fn intersects_terminate(self) -> bool
pub const fn intersects_terminate(self) -> bool
Returns true if the set shares any bit with Terminate.
Sourcepub const fn with_terminate(self) -> Self
pub const fn with_terminate(self) -> Self
Returns self with Terminate inserted.
Sourcepub const fn with_terminate_if(self, condition: bool) -> Self
pub const fn with_terminate_if(self, condition: bool) -> Self
Returns self with Terminate inserted if condition is true.
Sourcepub const fn without_terminate(self) -> Self
pub const fn without_terminate(self) -> Self
Returns self with Terminate removed.
Sourcepub const fn set_terminate(&mut self)
pub const fn set_terminate(&mut self)
Sets Terminate.
Sourcepub const fn set_terminate_if(&mut self, condition: bool)
pub const fn set_terminate_if(&mut self, condition: bool)
Sets Terminate if condition is true.
Sourcepub const fn unset_terminate(&mut self)
pub const fn unset_terminate(&mut self)
Unsets Terminate.
Sourcepub const fn has_hangup(self) -> bool
pub const fn has_hangup(self) -> bool
Returns true if Hangup is present.
Sourcepub const fn contains_hangup(self) -> bool
pub const fn contains_hangup(self) -> bool
Returns true if all bits in Hangup are present.
Sourcepub const fn intersects_hangup(self) -> bool
pub const fn intersects_hangup(self) -> bool
Returns true if the set shares any bit with Hangup.
Sourcepub const fn with_hangup(self) -> Self
pub const fn with_hangup(self) -> Self
Returns self with Hangup inserted.
Sourcepub const fn with_hangup_if(self, condition: bool) -> Self
pub const fn with_hangup_if(self, condition: bool) -> Self
Returns self with Hangup inserted if condition is true.
Sourcepub const fn without_hangup(self) -> Self
pub const fn without_hangup(self) -> Self
Returns self with Hangup removed.
Sourcepub const fn set_hangup(&mut self)
pub const fn set_hangup(&mut self)
Sets Hangup.
Sourcepub const fn set_hangup_if(&mut self, condition: bool)
pub const fn set_hangup_if(&mut self, condition: bool)
Sets Hangup if condition is true.
Sourcepub const fn unset_hangup(&mut self)
pub const fn unset_hangup(&mut self)
Unsets Hangup.
Sourcepub const fn has_suspend(self) -> bool
pub const fn has_suspend(self) -> bool
Returns true if Suspend is present.
Sourcepub const fn contains_suspend(self) -> bool
pub const fn contains_suspend(self) -> bool
Returns true if all bits in Suspend are present.
Sourcepub const fn intersects_suspend(self) -> bool
pub const fn intersects_suspend(self) -> bool
Returns true if the set shares any bit with Suspend.
Sourcepub const fn with_suspend(self) -> Self
pub const fn with_suspend(self) -> Self
Returns self with Suspend inserted.
Sourcepub const fn with_suspend_if(self, condition: bool) -> Self
pub const fn with_suspend_if(self, condition: bool) -> Self
Returns self with Suspend inserted if condition is true.
Sourcepub const fn without_suspend(self) -> Self
pub const fn without_suspend(self) -> Self
Returns self with Suspend removed.
Sourcepub const fn set_suspend(&mut self)
pub const fn set_suspend(&mut self)
Sets Suspend.
Sourcepub const fn set_suspend_if(&mut self, condition: bool)
pub const fn set_suspend_if(&mut self, condition: bool)
Sets Suspend if condition is true.
Sourcepub const fn unset_suspend(&mut self)
pub const fn unset_suspend(&mut self)
Unsets Suspend.
Sourcepub const fn has_resume(self) -> bool
pub const fn has_resume(self) -> bool
Returns true if Resume is present.
Sourcepub const fn contains_resume(self) -> bool
pub const fn contains_resume(self) -> bool
Returns true if all bits in Resume are present.
Sourcepub const fn intersects_resume(self) -> bool
pub const fn intersects_resume(self) -> bool
Returns true if the set shares any bit with Resume.
Sourcepub const fn with_resume(self) -> Self
pub const fn with_resume(self) -> Self
Returns self with Resume inserted.
Sourcepub const fn with_resume_if(self, condition: bool) -> Self
pub const fn with_resume_if(self, condition: bool) -> Self
Returns self with Resume inserted if condition is true.
Sourcepub const fn without_resume(self) -> Self
pub const fn without_resume(self) -> Self
Returns self with Resume removed.
Sourcepub const fn set_resume(&mut self)
pub const fn set_resume(&mut self)
Sets Resume.
Sourcepub const fn set_resume_if(&mut self, condition: bool)
pub const fn set_resume_if(&mut self, condition: bool)
Sets Resume if condition is true.
Sourcepub const fn unset_resume(&mut self)
pub const fn unset_resume(&mut self)
Unsets Resume.
Sourcepub const fn contains_close(self) -> bool
pub const fn contains_close(self) -> bool
Returns true if all bits in Close are present.
Sourcepub const fn intersects_close(self) -> bool
pub const fn intersects_close(self) -> bool
Returns true if the set shares any bit with Close.
Sourcepub const fn with_close(self) -> Self
pub const fn with_close(self) -> Self
Returns self with Close inserted.
Sourcepub const fn with_close_if(self, condition: bool) -> Self
pub const fn with_close_if(self, condition: bool) -> Self
Returns self with Close inserted if condition is true.
Sourcepub const fn without_close(self) -> Self
pub const fn without_close(self) -> Self
Returns self with Close removed.
Sourcepub const fn set_close_if(&mut self, condition: bool)
pub const fn set_close_if(&mut self, condition: bool)
Sets Close if condition is true.
Sourcepub const fn unset_close(&mut self)
pub const fn unset_close(&mut self)
Unsets Close.
Sourcepub const fn has_logout(self) -> bool
pub const fn has_logout(self) -> bool
Returns true if Logout is present.
Sourcepub const fn contains_logout(self) -> bool
pub const fn contains_logout(self) -> bool
Returns true if all bits in Logout are present.
Sourcepub const fn intersects_logout(self) -> bool
pub const fn intersects_logout(self) -> bool
Returns true if the set shares any bit with Logout.
Sourcepub const fn with_logout(self) -> Self
pub const fn with_logout(self) -> Self
Returns self with Logout inserted.
Sourcepub const fn with_logout_if(self, condition: bool) -> Self
pub const fn with_logout_if(self, condition: bool) -> Self
Returns self with Logout inserted if condition is true.
Sourcepub const fn without_logout(self) -> Self
pub const fn without_logout(self) -> Self
Returns self with Logout removed.
Sourcepub const fn set_logout(&mut self)
pub const fn set_logout(&mut self)
Sets Logout.
Sourcepub const fn set_logout_if(&mut self, condition: bool)
pub const fn set_logout_if(&mut self, condition: bool)
Sets Logout if condition is true.
Sourcepub const fn unset_logout(&mut self)
pub const fn unset_logout(&mut self)
Unsets Logout.
Sourcepub const fn has_shutdown(self) -> bool
pub const fn has_shutdown(self) -> bool
Returns true if Shutdown is present.
Sourcepub const fn contains_shutdown(self) -> bool
pub const fn contains_shutdown(self) -> bool
Returns true if all bits in Shutdown are present.
Sourcepub const fn intersects_shutdown(self) -> bool
pub const fn intersects_shutdown(self) -> bool
Returns true if the set shares any bit with Shutdown.
Sourcepub const fn with_shutdown(self) -> Self
pub const fn with_shutdown(self) -> Self
Returns self with Shutdown inserted.
Sourcepub const fn with_shutdown_if(self, condition: bool) -> Self
pub const fn with_shutdown_if(self, condition: bool) -> Self
Returns self with Shutdown inserted if condition is true.
Sourcepub const fn without_shutdown(self) -> Self
pub const fn without_shutdown(self) -> Self
Returns self with Shutdown removed.
Sourcepub const fn set_shutdown(&mut self)
pub const fn set_shutdown(&mut self)
Sets Shutdown.
Sourcepub const fn set_shutdown_if(&mut self, condition: bool)
pub const fn set_shutdown_if(&mut self, condition: bool)
Sets Shutdown if condition is true.
Sourcepub const fn unset_shutdown(&mut self)
pub const fn unset_shutdown(&mut self)
Unsets Shutdown.
Sourceimpl AppControlSet
Common set methods
impl AppControlSet
Common set methods
Sourceimpl AppControlSet
Set operations
impl AppControlSet
Set operations
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns true if self and other share any bit.
Sourcepub const fn is_subset(self, other: Self) -> bool
pub const fn is_subset(self, other: Self) -> bool
Returns true if all bits in self are also set in other.
Sourcepub const fn is_superset(self, other: Self) -> bool
pub const fn is_superset(self, other: Self) -> bool
Returns true if all bits in other are also set in self.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection of self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference of self and other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference of self and other.
Sourceimpl AppControlSet
Mutating set operations
impl AppControlSet
Mutating set operations